Linear Algebra
==============

.. autoclass:: pyhmmer.easel.Vector
   :members:

.. autoclass:: pyhmmer.easel.VectorF(Vector)
   :special-members: __init__
   :members:

.. autoclass:: pyhmmer.easel.VectorD(Vector)
   :special-members: __init__
   :members:

.. autoclass:: pyhmmer.easel.VectorU8(Vector)
   :special-members: __init__
   :members:


.. autoclass:: pyhmmer.easel.Matrix
   :members:

.. autoclass:: pyhmmer.easel.MatrixD
   :special-members: __init__
   :members:

.. autoclass:: pyhmmer.easel.MatrixF
   :special-members: __init__
   :members:

.. autoclass:: pyhmmer.easel.MatrixU8
   :special-members: __init__
   :members: